@@ -10,7 +10,7 @@ describe 'glance::api' do
   let :default_params do
     {
       :bind_host                      => '<SERVICE DEFAULT>',
-      :bind_port                      => '9292',
+      :bind_port                      => '<SERVICE DEFAULT>',
       :auth_strategy                  => 'keystone',
       :enabled                        => true,
       :manage_service                 => true,
@@ -195,6 +195,7 @@ describe 'glance::api' do
             'filesystem_store_file_perm',
           ].each do |config|
             is_expected.to contain_glance_api_config("glance_store/#{config}").with_value(param_hash[config.intern])
+            is_expected.to contain_glance_cache_config("glance_store/#{config}").with_value(param_hash[config.intern])
           end
         end
 
@@ -295,39 +296,13 @@ describe 'glance::api' do
       it_raises 'a Puppet::Error', /Invalid service_name/
     end
 
-    describe 'with blank flavor' do
-      let :params do
-        {
-          :paste_deploy_flavor => '',
-        }
-      end
-
-      it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_ensure('absent') }
-    end
-
-    [
-      'keystone/',
-      'keystone+',
-      '+keystone',
-      'keystone+cachemanagement+',
-      '+'
-    ].each do |flavor|
-      describe "with flavor set by incorrect value #{flavor}" do
-        let :params do
-          {
-            :flavor => flavor
-          }
-        end
-
-        it { expect { is_expected.to contain_glance_api_config('filter:paste_deploy/flavor') }.to\
-          raise_error(Puppet::Error) }
-      end
-    end
-
     describe 'with platform default oslo concurrency lock_path' do
       it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
         :lock_path => platform_params[:lock_path]
       )}
+      it { is_expected.to contain_oslo__concurrency('glance_cache_config').with(
+        :lock_path => platform_params[:lock_path]
+      )}
     end
 
     describe 'with overridden oslo concurrency lock_path' do
@@ -338,6 +313,9 @@ describe 'glance::api' do
       it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
         :lock_path => '/glance/lock/path',
       )}
+      it { is_expected.to contain_oslo__concurrency('glance_cache_config').with(
+        :lock_path => '/glance/lock/path',
+      )}
     end
 
     describe 'setting enable_proxy_headers_parsing' do
@@ -391,6 +369,9 @@ describe 'glance::api' do
     describe 'with enabled_backends and stores by default' do
       it { is_expected.to_not contain_glance_api_config('DEFAULT/enabled_backends').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
+
+      it { is_expected.to_not contain_glance_cache_config('DEFAULT/enabled_backends').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to_not contain_glance_cache_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'with enabled_backends' do
@@ -407,6 +388,11 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('glance_store/default_backend').with_value('file1') }
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_ensure('absent') }
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_ensure('absent') }
+
+      it { is_expected.to contain_glance_cache_config('DEFAULT/enabled_backends').with_value('file1:file,http1:http') }
+      it { is_expected.to contain_glance_cache_config('glance_store/default_backend').with_value('file1') }
+      it { is_expected.to contain_glance_cache_config('glance_store/stores').with_ensure('absent') }
+      it { is_expected.to contain_glance_cache_config('glance_store/default_store').with_ensure('absent') }
     end
 
     describe 'with invalid backend type' do
@@ -463,6 +449,9 @@ describe 'glance::api' do
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file,http') }
+
+      it { is_expected.to contain_glance_cache_config('glance_store/default_store').with_value('file') }
+      it { is_expected.to contain_glance_cache_config('glance_store/stores').with_value('file,http') }
     end
 
     describe 'with single store override and no default store' do
@@ -475,6 +464,9 @@ describe 'glance::api' do
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file') }
+
+      it { is_expected.to contain_glance_cache_config('glance_store/default_store').with_value('file') }
+      it { is_expected.to contain_glance_cache_config('glance_store/stores').with_value('file') }
     end
 
     describe 'with multiple stores override and no default store' do
@@ -487,6 +479,9 @@ describe 'glance::api' do
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file,http') }
+
+      it { is_expected.to contain_glance_cache_config('glance_store/default_store').with_value('file') }
+      it { is_expected.to contain_glance_cache_config('glance_store/stores').with_value('file,http') }
     end
 
     describe 'with default_store' do
@@ -499,6 +494,9 @@ describe 'glance::api' do
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file') }
+
+      it { is_expected.to contain_glance_cache_config('glance_store/default_store').with_value('file') }
+      it { is_expected.to contain_glance_cache_config('glance_store/stores').with_value('file') }
     end
 
     describe 'with task & taskflow configuration' do
@@ -534,6 +532,7 @@ describe 'glance::api' do
         end
         it { is_expected.to contain_package('glance-api').with(
           :ensure => package_ensure,
+          :name   => 'glance-api',
           :tag    => ['openstack', 'glance-package']
         )}
       end
@@ -549,7 +548,7 @@ describe 'glance::api' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :lock_path => '/var/lock/glance' }
         when 'RedHat'
@@ -558,8 +557,8 @@ describe 'glance::api' do
       end
 
       it_configures 'glance::api'
-      if facts[:osfamily] == 'Debian'
-        it_configures "glance::api on #{facts[:osfamily]}"
+      if facts[:os]['family'] == 'Debian'
+        it_configures "glance::api on #{facts[:os]['family']}"
       end
     end
   end
