@@ -22,7 +22,7 @@ describe 'glance::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-glanceclient' }
         when 'RedHat'
