@@ -40,6 +40,7 @@ describe 'glance::backend::multistore::swift' do
 
       it 'configures glance-api.conf' do
         is_expected.to contain_glance_api_config('swift/store_description').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('swift/weight').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_large_object_chunk_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_container').with_value('<SERVICE DEFAULT>')
@@ -52,6 +53,24 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_buffer_on_upload').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_upload_buffer_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_retry_get_count').with_value('<SERVICE DEFAULT>')
+      end
+      it 'configures glance-cache.conf' do
+        is_expected.to_not contain_glance_cache_config('swift/store_description')
+        is_expected.to contain_glance_cache_config('swift/weight').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_large_object_chunk_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_container').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_endpoint_type').with_value('internalURL')
+        is_expected.to contain_glance_cache_config('swift/swift_store_service_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_region').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
+        is_expected.to contain_glance_cache_config('swift/default_swift_reference').with_value('ref1')
+        is_expected.to contain_glance_cache_config('swift/swift_buffer_on_upload').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_upload_buffer_dir').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_cache_config('swift/swift_store_retry_get_count').with_value('<SERVICE DEFAULT>')
+      end
+      it 'configures glance-swift.conf' do
         is_expected.to contain_glance_swift_config('ref1/key').with_value('key').with_secret(true)
         is_expected.to contain_glance_swift_config('ref1/user').with_value('user')
         is_expected.to contain_glance_swift_config('ref1/auth_version').with_value('3')
@@ -65,6 +84,7 @@ describe 'glance::backend::multistore::swift' do
       let :params do
         {
           :store_description                   => 'My swift store',
+          :weight                              => 0,
           :swift_store_user                    => 'user2',
           :swift_store_key                     => 'key2',
           :swift_store_auth_version            => '1',
@@ -88,6 +108,7 @@ describe 'glance::backend::multistore::swift' do
 
       it 'configures glance-api.conf' do
         is_expected.to contain_glance_api_config('swift/store_description').with_value('My swift store')
+        is_expected.to contain_glance_api_config('swift/weight').with_value(0)
         is_expected.to contain_glance_api_config('swift/swift_store_container').with_value('swift')
         is_expected.to contain_glance_api_config('swift/swift_store_create_container_on_put').with_value(true)
         is_expected.to contain_glance_api_config('swift/swift_store_large_object_size').with_value('100')
@@ -100,6 +121,24 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_buffer_on_upload').with_value(true)
         is_expected.to contain_glance_api_config('swift/swift_upload_buffer_dir').with_value('/var/glance/swift')
         is_expected.to contain_glance_api_config('swift/swift_store_retry_get_count').with_value(3)
+      end
+      it 'configures glance-cache.conf' do
+        is_expected.to_not contain_glance_cache_config('swift/store_description')
+        is_expected.to contain_glance_cache_config('swift/weight').with_value(0)
+        is_expected.to contain_glance_cache_config('swift/swift_store_container').with_value('swift')
+        is_expected.to contain_glance_cache_config('swift/swift_store_create_container_on_put').with_value(true)
+        is_expected.to contain_glance_cache_config('swift/swift_store_large_object_size').with_value('100')
+        is_expected.to contain_glance_cache_config('swift/swift_store_large_object_chunk_size').with_value('50')
+        is_expected.to contain_glance_cache_config('swift/swift_store_endpoint_type').with_value('publicURL')
+        is_expected.to contain_glance_cache_config('swift/swift_store_service_type').with_value('object-store')
+        is_expected.to contain_glance_cache_config('swift/swift_store_region').with_value('RegionTwo')
+        is_expected.to contain_glance_cache_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift2.conf')
+        is_expected.to contain_glance_cache_config('swift/default_swift_reference').with_value('swift_creds')
+        is_expected.to contain_glance_cache_config('swift/swift_buffer_on_upload').with_value(true)
+        is_expected.to contain_glance_cache_config('swift/swift_upload_buffer_dir').with_value('/var/glance/swift')
+        is_expected.to contain_glance_cache_config('swift/swift_store_retry_get_count').with_value(3)
+      end
+      it 'configures glance-swift.conf' do
         is_expected.to contain_glance_swift_config('swift_creds/key').with_value('key2').with_secret(true)
         is_expected.to contain_glance_swift_config('swift_creds/user').with_value('user2')
         is_expected.to contain_glance_swift_config('swift_creds/auth_version').with_value('1')
